==> nextcloud-25.0.12.tgz: nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privāts",
    "Local" : "Lokāls",
    "Federated" : "Federated",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Apps" : "Lietotnes",
    "Wrong password" : "Nepareiza parole",
    "Saved" : "Saglabāts",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Administrator documentation" : "Administratora dokumentācija",
    "User documentation" : "Lietotāja dokumentācija",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "Users" : "Lietotāji",
    "Invalid user" : "Nepareizs lietotājs",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Settings" : "Iestatījumi",
    "Personal" : "Personīgs",
    "Administration" : "Administrēšana",
    "Additional settings" : "Papildu iestatījumi",
    "Administration privileges" : "Administrēšanas privilēģijas",
    "Sharing" : "Koplietošana",
    "Availability" : "Pieejamība",
    "Calendar" : "Kalendārs",
    "Personal info" : "Personiskā informācija",
    "Email server" : "E-pasta serveris",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Delete" : "Dzēst",
    "Unlimited" : "Neierobežota",
    "Nextcloud settings" : "Nextcloud iestatījumi",
    "None" : "Nav",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "Visit website" : "Apmeklējiet vietni",
    "Report a bug" : "Ziņot par kļūdu",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "Icon" : "Ikona",
    "Name" : "Vārds",
    "Version" : "Versija",
    "Actions" : "Darbības",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Device settings" : "Ierīces iestatījumi",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Done" : "Pabeigts",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Profile" : "Profils",
    "Enable" : "Aktivēt",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Cancel" : "Atcelt",
    "Details" : "Detaļas",
    "Your email address" : "Jūsu e-pasta adrese",
    "No email address set" : "Nav norādīts e-pasts",
    "Language" : "Valoda",
    "Help translate" : "Palīdzi tulkot",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Your website" : "Jūsu mājaslapa",
    "Add" : "Pievienot",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Quota" : "Apjoms",
    "Avatar" : "Profila attēls",
    "Group admin for" : "Admin grupa",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Edit" : "Rediģēt",
    "Show last login" : "Rādīt pēdējo autorizāciju",
    "Send email" : "Sūtīt e-pastu",
    "Default quota" : "Apjoms pēc noklusējuma",
    "Changelog" : "Izmaiņu žurnāls",
    "Add group" : "Pievienot grupu",
    "Active users" : "Aktīvie lietotāji",
    "Admins" : "Admins",
    "Not saved" : "Nav saglabāts",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Location" : "Vieta",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Full name" : "Pilns vārds",
    "Phone number" : "Tālruņa numurs",
    "Twitter" : "Twitter",
    "Website" : "Mājaslapa",
    "Updates" : "Atjauninājumi",
    "Hide" : "Slēpt",
    "Never" : "Nekad",
    "Documentation" : "Dokumentācija",
    "Forum" : "Forums",
    "Login" : "Autorizēties",
    "SSL" : "SSL",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Authentication" : "Autentifikācija",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Autentifikācijas metode"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-26.0.9.tgz: nextcloud/apps/settings/l10n/lv.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privāts",
    "Local" : "Lokāls",
    "Federated" : "Federated",
    "Verify" : "Verificēt",
    "Unable to change password" : "Nav iespējams nomainīt paroli",
    "Very weak password" : "Ļoti vāja parole",
    "Weak password" : "Vāja parole",
    "So-so password" : "Normāla parole",
    "Good password" : "Laba parole",
    "Strong password" : "Lieliska parole",
    "Groups" : "Grupas",
    "Group list is empty" : "Grupu saraksts ir tukšš",
    "Unable to retrieve the group list" : "Nevarēja saņemt grupu sarakstu",
    "You successfully logged in using two-factor authentication (%1$s)" : "Esat veiksmīgi pieteicies, izmantojot divpakāpju autentifikācija (%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "Pieteikšanās mēģinājums, izmantojot divpakāpju autentifikāciju neizdevās (%1$s)",
    "Apps" : "Lietotnes",
    "Wrong password" : "Nepareiza parole",
    "Saved" : "Saglabāts",
    "No user supplied" : "Nav norādīts lietotājs",
    "Authentication error" : "Autentifikācijas kļūda",
    "Wrong admin recovery password. Please check the password and try again." : "Nepareiza administratora atjaunošanas parole. Lūdzu pārbaudiet paroli un mēģiniet vēlreiz.",
    "Federated Cloud Sharing" : "Federatīva mākoņkoplietošana",
    "Administrator documentation" : "Administratora dokumentācija",
    "User documentation" : "Lietotāja dokumentācija",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Radās kļūda, nosūtot e-pastu. Lūdzu, pārskatiet savus iestatījumus. (Kļūda: %s)",
    "Users" : "Lietotāji",
    "Invalid user" : "Nepareizs lietotājs",
    "Invalid mail address" : "Nepareiza e-pasta adrese",
    "Settings saved" : "Iestatījumi saglabāti",
    "Unable to change full name" : "Nav iespējams nomainīt jūsu pilno vārdu",
    "Unable to change email address" : "Nevar mainīt e-pasta adresi",
    "Your %s account was created" : "Konts %s ir izveidots",
    "Settings" : "Iestatījumi",
    "Personal" : "Personīgs",
    "Administration" : "Administrēšana",
    "Additional settings" : "Papildu iestatījumi",
    "Administration privileges" : "Administrēšanas privilēģijas",
    "Sharing" : "Koplietošana",
    "Availability" : "Pieejamība",
    "Calendar" : "Kalendārs",
    "Personal info" : "Personiskā informācija",
    "Email server" : "E-pasta serveris",
    "Security & setup warnings" : "Drošības un iestatījumu brīdinājumi",
    "Unlimited" : "Neierobežota",
    "Disabled" : "Atspējots",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP nešķiet pareizi uzstādīts lai veiktu sistēmas vides mainīgo vaicājumus. Tests ar getenv(\"PATH\") atgriež tikai tukšu atbildi.",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Ir iespējots tikai lasāma konfigurācija. Tas neatļauj iestatīt un mainīt dažas konfigurācijas caur tīmekļa interfeisu. Šī datne būs manuāli jāpārveido par rakstāmu, pirms katra atjauninājuma instalēšanas.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Jūsu datubāze neiet ar \"READ COMMITED\" transakciju izolācijas līmeni. Tas var radīt problēmas kad vairākas darbības tiek veiktas pararēli.",
    "Nextcloud settings" : "Nextcloud iestatījumi",
    "None" : "Nav",
    "Allow apps to use the Share API" : "Ļaut programmām izmantot koplietošanas API",
    "Allow resharing" : "Atļaut atkārtotu koplietošanu",
    "Allow sharing with groups" : "Atļaut koplietošanu ar grupām",
    "Restrict users to only share with users in their groups" : "Ierobežot lietotājiem koplietot tikai ar lietotājiem savās grupās",
    "Allow public uploads" : "Atļaut publisko augšupielādi",
    "Enforce password protection" : "Ieviest paroles aizsardzību",
    "Exclude groups from sharing" : "Izslēgt grupas no koplietošanas",
    "Enforce expiration date" : "Uzspiest beigu termiņu",
    "Limit to groups" : "Grupu ierobežojums",
    "Save changes" : "Saglabāt izmaiņas",
    "All" : "Visi",
    "No results" : "Nav rezultātu",
    "Update to {version}" : "Atjaunināts uz {version}",
    "Remove" : "Izņemt",
    "Disable" : "Deaktivēt",
    "Visit website" : "Apmeklējiet vietni",
    "Report a bug" : "Ziņot par kļūdu",
    "Admin documentation" : "Administratora dokumentācija",
    "Developer documentation" : "Izstrādātāja dokumentācija",
    "Icon" : "Ikona",
    "Name" : "Vārds",
    "Version" : "Versija",
    "Actions" : "Darbības",
    "No apps found for your version" : "Neatrada lietotnes jūsu versijai",
    "Device settings" : "Ierīces iestatījumi",
    "Rename" : "Pārsaukt",
    "Revoke" : "Atsaukt",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "iPhone" : "iPhone",
    "Sync client - {os}" : "Sync klients - {os}",
    "This session" : "Šajā sesijā",
    "Device" : "Ierīce",
    "Last activity" : "Pēdējās darbības",
    "App name" : "Lietotnes nosaukums",
    "Create new app password" : "Izveidot jaunu lietotnes paroli",
    "Use the credentials below to configure your app or device." : "Izmantot akreditācijas datus, lai konfigurētu savu lietotni vai ierīci.",
    "For security reasons this password will only be shown once." : "Drošības apsvērumu dēļ šī parole, tiks parādīta tikai vienreiz.",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Done" : "Pabeigts",
    "Copied!" : "Nokopēts!",
    "Copy" : "Kopēt",
    "Profile" : "Profils",
    "Enable" : "Aktivēt",
    "Server-side encryption" : "Servera šifrēšana",
    "Enable server-side encryption" : "Ieslēgt servera šifrēšanu",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Šifrēšana vien negarantē sistēmas drošību. Skatiet dokumentāciju, lai iegūtu papildinformāciju par šifrēšanas lietotnes izmantošanu un atbalstītajiem izmantošanas veidiem.",
    "Be aware that encryption always increases the file size." : "Jāapzinās, ka šifrēšanas vienmēr palielina datnes lielumu.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Vienmēr ir ieteicams regulāri veidot dublējumkopijas datu šifrēšanas gadījumam, pārliecinieties, lai dublētu, šifrēšanas atslēgas ir kopā ar jūsu datiem.",
    "This is the final warning: Do you really want to enable encryption?" : "Šis ir pēdējais brīdinājums: vai tiešām vēlaties iespējot šifrēšanu?",
    "No encryption module loaded, please enable an encryption module in the app menu." : "Nav ielādēts šifrēšanas moduļis, lūdzu, aktivizējiet šifrēšanas moduli lietotņu izvēlnē.",
    "Select default encryption module:" : "Atlasiet noklusēto šifrēšanas moduli:",
    "Cancel" : "Atcelt",
    "Confirm" : "Apstiprināt",
    "Submit" : "Iesniegt",
    "Current password" : "Pašreizējā parole",
    "New password" : "Jauna parole",
    "Change password" : "Mainīt paroli",
    "Details" : "Detaļas",
    "No email address set" : "Nav norādīts e-pasts",
    "Help translate" : "Palīdzi tulkot",
    "Your phone number" : "Jūsu tālruņa numurs",
    "Your website" : "Jūsu mājaslapa",
    "Add" : "Pievienot",
    "Create" : "Izveidot",
    "Change" : "Mainīt",
    "Delete" : "Dzēst",
    "Display name" : "Ekrāna vārds",
    "Email" : "E-pasts",
    "Quota" : "Apjoms",
    "Language" : "Valoda",
    "Avatar" : "Profila attēls",
    "Group admin for" : "Admin grupa",
    "Storage location" : "Krātuves atrašanās vieta",
    "Last login" : "Pēdējā pieteikšanās",
    "Edit" : "Rediģēt",
    "Show last login" : "Rādīt pēdējo autorizāciju",
    "Send email" : "Sūtīt e-pastu",
    "Default quota" : "Apjoms pēc noklusējuma",
    "Changelog" : "Izmaiņu žurnāls",
    "Active users" : "Aktīvie lietotāji",
    "Admins" : "Admins",
    "Group name" : "Grupas nosaukums",
    "Sending…" : "Sūta …",
    "Email sent" : "Vēstule nosūtīta",
    "Location" : "Vieta",
    "Profile picture" : "Profila attēls",
    "About" : "Par",
    "Full name" : "Pilns vārds",
    "Phone number" : "Tālruņa numurs",
    "Website" : "Mājaslapa",
    "Updates" : "Atjauninājumi",
    "Hide" : "Slēpt",
    "Never" : "Nekad",
    "Documentation" : "Dokumentācija",
    "Forum" : "Forums",
    "Login" : "Autorizēties",
    "SSL" : "SSL",
    "Open documentation" : "Atvērt dokumentāciju",
    "Send mode" : "Sūtīšanas metode",
    "Encryption" : "Šifrēšana",
    "From address" : "No adreses",
    "Server address" : "Servera adrese",
    "Port" : "Ports",
    "Authentication" : "Autentifikācija",
    "Authentication required" : "Nepieciešama autentifikācija",
    "Credentials" : "Akreditācijas dati",
    "SMTP Username" : "SMTP lietotājvārds",
    "SMTP Password" : "SMTP parole",
    "Save" : "Saglabāt",
    "All checks passed." : "Visas pārbaudes veiksmīgas.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Izstrādātās {communityopen}Nextcloud kopiena {linkclose},  {githubopen} avota kods {linkclose} licencēts saskaņā ar {licenseopen}AGPL{linkclose}.",
    "png or jpg, max. 20 MB" : "png vai jpg, max. 20 MB",
    "Your email address" : "Jūsu e-pasta adrese",
    "Add group" : "Pievienot grupu",
    "Send email to new user" : "Sūtīt e-pastu jaunajam lietotājam",
    "Not saved" : "Nav saglabāts",
    "Twitter" : "Twitter",
    "Plain" : "vienkāršs teksts",
    "NT LAN Manager" : "NT LAN Pārvaldnieks",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Authentication method" : "Autentifikācijas metode",
    "Set default expiration date" : "Iestatīt noklusējuma beigu datumu"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
